@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckFile;
 # ABSTRACT: Git::Hooks plugin for checking files
-$Git::Hooks::CheckFile::VERSION = '2.5.0';
+$Git::Hooks::CheckFile::VERSION = '2.5.1';
 use 5.010;
 use utf8;
 use strict;
@@ -223,13 +223,16 @@ sub check_patchset {
     return check_new_files($git, $opts->{'--commit'}, $git->filter_files_in_commit('AM', $opts->{'--commit'}));
 }
 
-# Install hooks
-PRE_COMMIT       \&check_commit;
-UPDATE           \&check_affected_refs;
-PRE_RECEIVE      \&check_affected_refs;
-REF_UPDATE       \&check_affected_refs;
-PATCHSET_CREATED \&check_patchset;
-DRAFT_PUBLISHED  \&check_patchset;
+INIT: {
+    # Install hooks
+    PRE_APPLYPATCH   \&check_commit;
+    PRE_COMMIT       \&check_commit;
+    UPDATE           \&check_affected_refs;
+    PRE_RECEIVE      \&check_affected_refs;
+    REF_UPDATE       \&check_affected_refs;
+    PATCHSET_CREATED \&check_patchset;
+    DRAFT_PUBLISHED  \&check_patchset;
+}
 
 1;
 
@@ -245,7 +248,7 @@ Git::Hooks::CheckFile - Git::Hooks plugin for checking files
 
 =head1 VERSION
 
-version 2.5.0
+version 2.5.1
 
 =head1 SYNOPSIS
 
@@ -295,6 +298,8 @@ specified constraints. If they don't, the commit/push is aborted.
 
 =over
 
+=item * B<pre-applypatch>
+
 =item * B<pre-commit>
 
 =item * B<update>
