@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '2.5.0';
+$Git::Hooks::CheckJira::VERSION = '2.5.1';
 use 5.010;
 use utf8;
 use strict;
@@ -571,14 +571,17 @@ EOS
     return $errors == 0;
 }
 
-# Install hooks
-COMMIT_MSG       \&check_message_file;
-UPDATE           \&check_affected_refs;
-PRE_RECEIVE      \&check_affected_refs;
-REF_UPDATE       \&check_affected_refs;
-POST_RECEIVE     \&notify_affected_refs;
-PATCHSET_CREATED \&check_patchset;
-DRAFT_PUBLISHED  \&check_patchset;
+INIT: {
+    # Install hooks
+    APPLYPATCH_MSG   \&check_message_file;
+    COMMIT_MSG       \&check_message_file;
+    UPDATE           \&check_affected_refs;
+    PRE_RECEIVE      \&check_affected_refs;
+    REF_UPDATE       \&check_affected_refs;
+    POST_RECEIVE     \&notify_affected_refs;
+    PATCHSET_CREATED \&check_patchset;
+    DRAFT_PUBLISHED  \&check_patchset;
+}
 1;
 
 __END__
@@ -593,7 +596,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 2.5.0
+version 2.5.1
 
 =head1 SYNOPSIS
 
@@ -653,7 +656,7 @@ request (a.k.a. ticket) open.
 
 =over
 
-=item * B<commit-msg>
+=item * B<commit-msg>, B<applypatch-msg>
 
 This hook is invoked during the commit, to check if the commit message
 cites valid JIRA issues.
